@@ -1,5 +1,6 @@
 pub use self::{
     basis::TailwindBasis,
+    content::{content_align::TailwindContentAlign, TailwindContent},
     flex::{flex_adaptor, flex_direction::TailwindFlexDirection, flex_wrap::TailwindFlexWrap, TailwindFlex},
     gap::TailwindGap,
     grid::{
@@ -7,11 +8,15 @@ pub use self::{
         TailwindGrid,
     },
     grow::TailWindGrow,
+    items::TailwindItems,
     justify::{justify_content::TailwindJustifyContent, justify_item::TailwindJustifyItems, justify_self::TailwindJustifySelf},
     order::TailWindOrder,
-    place::{place_content::TailwindPlaceContent, place_item::TailwindPlaceItems, place_self::TailwindPlaceSelf},
+    place::{
+        place_content::TailwindPlaceContent, place_item::TailwindPlaceItems, place_self::TailwindPlaceSelf, TailwindPlace,
+    },
     shrink::TailWindShrink,
     span::{TailwindColumn, TailwindRow},
+    zelf::TailwindSelf,
 };
 use crate::{
     css_attributes, syntax_error, CssAttribute, CssBehavior, LengthUnit, Result, TailwindArbitrary, TailwindBuilder,
@@ -24,46 +29,17 @@ use std::{
 use tailwind_ast::parse_integer;
 
 mod basis;
-mod display;
+mod content;
 mod flex;
 mod gap;
 mod grid;
 mod grow;
+mod items;
 mod justify;
 mod order;
-mod parser;
 mod place;
 mod shrink;
 mod span;
-
-#[doc=include_str!("align-content.md")]
-#[derive(Debug, Copy, Clone)]
-pub enum TailwindContent {
-    // Auto,
-    Start,
-    End,
-    Center,
-    Between,
-    Around,
-    Evenly,
-}
-
-#[doc=include_str!("align-items.md")]
-#[derive(Debug, Copy, Clone)]
-pub enum TailwindItems {
-    Auto,
-    Start,
-    End,
-    Center,
-    Stretch,
-}
-
-#[doc=include_str!("align-self.md")]
-#[derive(Debug, Copy, Clone)]
-pub enum TailwindSelf {
-    Auto,
-    Start,
-    End,
-    Center,
-    Stretch,
-}
+#[cfg(test)]
+mod test;
+mod zelf;
