@@ -5,14 +5,15 @@ impl TailwindInstruction {
     #[inline(never)]
     pub fn get_instance(&self) -> Result<Box<dyn TailwindInstance>> {
         let element = self.view_elements();
+        let pattern = element.as_slice();
         let arbitrary = self.view_arbitrary();
         let neg = self.negative;
-        let instance = match element.as_slice() {
+        let instance = match pattern {
             // Layout System
             ["aspect", rest @ ..] => TailwindAspect::parse(rest, arbitrary)?.boxed(),
             ["container"] => TailwindContainer::default().boxed(),
             ["columns", rest @ ..] => TailwindColumns::parse(rest, arbitrary)?.boxed(),
-            ["break", rest @ ..] => Self::break_adaptor(rest, arbitrary)?,
+            ["break", rest @ ..] => TailwindBreak::parse(rest, arbitrary)?,
             ["box", rest @ ..] => Self::box_adaptor(rest, arbitrary)?,
             // begin https://tailwindcss.com/docs/display
             ["block"] => TailwindDisplay::from("block").boxed(),
@@ -41,7 +42,7 @@ impl TailwindInstruction {
             ["clear", rest @ ..] => TailwindClear::parse(rest, arbitrary)?.boxed(),
             ["isolate"] => TailwindIsolation::from("isolate").boxed(),
             ["isolation", rest @ ..] => TailwindIsolation::parse(rest, arbitrary)?.boxed(),
-            ["object", rest @ ..] => object_adaptor(rest, arbitrary)?,
+            ["object", rest @ ..] => Self::object_adaptor(rest, arbitrary)?,
             ["overflow", rest @ ..] => Self::overflow_adaptor(rest, arbitrary)?,
             ["overscroll", rest @ ..] => Self::overscroll_adaptor(rest, arbitrary)?,
             // https://tailwindcss.com/docs/position#header
@@ -53,8 +54,8 @@ impl TailwindInstruction {
             ["bottom", rest @ ..] => TailwindBottom::parse(rest, arbitrary, neg)?.boxed(),
             ["left", rest @ ..] => TailwindLeft::parse(rest, arbitrary, neg)?.boxed(),
             // https://tailwindcss.com/docs/visibility
-            ["visible"] => TailwindVisibility::Visible.boxed(),
-            ["invisible"] => TailwindVisibility::Invisible.boxed(),
+            ["visible"] => TailwindVisibility::from("visible").boxed(),
+            ["invisible"] => TailwindVisibility::from("hidden").boxed(),
             // https://tailwindcss.com/docs/z-index
             ["z", rest @ ..] => TailWindZIndex::parse(rest, arbitrary, self.negative)?.boxed(),
             // Flexbox & Grid
@@ -70,18 +71,15 @@ impl TailwindInstruction {
             ["auto", rest @ ..] => TailwindGridAuto::parse(rest, arbitrary)?.boxed(),
             ["gap", rest @ ..] => TailwindGap::parse(rest, arbitrary)?.boxed(),
             ["justify", rest @ ..] => Self::justify_adaptor(rest, arbitrary)?,
-            ["content", rest @ ..] => Self::content_adaptor(rest, arbitrary)?,
+            ["content", rest @ ..] => TailwindContent::parse(rest, arbitrary)?,
             ["items", rest @ ..] => TailwindItems::parse(rest, arbitrary)?.boxed(),
             ["self", rest @ ..] => TailwindSelf::parse(rest, arbitrary)?.boxed(),
-            ["place", rest @ ..] => Self::place_adaptor(rest, arbitrary)?,
+            ["place", rest @ ..] => TailwindPlace::parse(rest, arbitrary)?,
             // justify catched
             // Spacing System
-            [p @ ("p" | "pl" | "pr" | "pm" | "pt" | "px" | "py"), rest @ ..] =>
-                TailwindSpacing::parse_padding(rest, p, arbitrary)?.boxed(),
-            [m @ ("m" | "ml" | "mr" | "mm" | "mt" | "mx" | "my"), rest @ ..] =>
-                TailwindSpacing::parse_margin(rest, m, arbitrary)?.boxed(),
-            ["space", "x", rest @ ..] => TailwindSpacing::parse_space(rest, 'x', arbitrary)?.boxed(),
-            ["space", "y", rest @ ..] => TailwindSpacing::parse_space(rest, 'y', arbitrary)?.boxed(),
+            ["p" | "pl" | "pr" | "pm" | "pt" | "px" | "py", ..] => TailwindPadding::parse(pattern, arbitrary, neg)?.boxed(),
+            ["m" | "ml" | "mr" | "mm" | "mt" | "mx" | "my", ..] => TailwindMargin::parse(pattern, arbitrary, neg)?.boxed(),
+            ["space", rest @ ..] => TailwindSpace::parse(rest, arbitrary, neg)?,
             // Sizing System
             ["w", rest @ ..] => TailwindSizing::parse_width(rest, arbitrary)?.boxed(),
             ["min", "w", rest @ ..] => TailwindSizing::parse_width_min(rest, arbitrary)?.boxed(),
@@ -141,7 +139,7 @@ impl TailwindInstruction {
             // Borders System
             ["rounded", rest @ ..] => TailwindRounded::parse(rest, arbitrary)?.boxed(),
             ["border", rest @ ..] => TailwindBorder::parse(rest, arbitrary)?,
-            ["divide", rest @ ..] => Self::divide_adaptor(rest, arbitrary)?,
+            ["divide", rest @ ..] => TailwindDivide::parse(rest, arbitrary)?,
             ["outline", rest @ ..] => outline_adaptor(rest, arbitrary)?,
             ["ring", rest @ ..] => Self::ring_adaptor(rest, arbitrary)?,
             // Effects System
@@ -176,13 +174,13 @@ impl TailwindInstruction {
             // Interactivity System
             ["accent", rest @ ..] => TailwindAccentColor::parse(rest, arbitrary)?.boxed(),
             // https://tailwindcss.com/docs/appearance
-            ["appearance", "none"] => TailwindAppearance::None.boxed(),
+            ["appearance", rest @ ..] => TailwindAppearance::parse(rest, arbitrary)?.boxed(),
             ["cursor", rest @ ..] => TailwindCursor::parse(rest, arbitrary)?.boxed(),
             ["caret", rest @ ..] => TailwindCaretColor::parse(rest, arbitrary)?.boxed(),
             ["pointer", "events", rest @ ..] => TailwindPointerEvents::parse(rest, arbitrary)?.boxed(),
             ["resize", rest @ ..] => TailwindResize::parse(rest, arbitrary)?.boxed(),
-            ["scroll", rest @ ..] => TailwindScroll::parse(rest, arbitrary)?.boxed(),
-            ["snap", rest @ ..] => TailwindSnap::parse(rest, arbitrary)?.boxed(),
+            ["scroll", rest @ ..] => TailwindScroll::parse(rest, arbitrary, neg)?,
+            ["snap", rest @ ..] => TailwindSnap::parse(rest, arbitrary)?,
             ["touch", rest @ ..] => TailwindTorch::parse(rest, arbitrary)?.boxed(),
             ["select", rest @ ..] => TailwindSelect::parse(rest, arbitrary)?.boxed(),
             ["will", "change", rest @ ..] => TailwindWillChange::parse(rest, arbitrary)?.boxed(),
@@ -198,23 +196,6 @@ impl TailwindInstruction {
         Ok(instance)
     }
     #[inline]
-    fn break_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
-        let out = match str {
-            // https://tailwindcss.com/docs/border-style
-            ["normal"] => TailwindBreakWord::Normal.boxed(),
-            ["words"] => TailwindBreakWord::Words.boxed(),
-            ["all"] => TailwindBreakWord::All.boxed(),
-            // https://tailwindcss.com/docs/break-before
-            ["before", rest @ ..] => TailwindBreakBefore::parse(rest, arbitrary)?.boxed(),
-            // https://tailwindcss.com/docs/break-inside
-            ["inside", rest @ ..] => TailwindBreakInside::parse(rest, arbitrary)?.boxed(),
-            // https://tailwindcss.com/docs/break-after
-            ["after", rest @ ..] => TailwindBreakAfter::parse(rest, arbitrary)?.boxed(),
-            _ => return syntax_error!("Unknown break instructions: {}", str.join("-")),
-        };
-        Ok(out)
-    }
-    #[inline]
     fn bg_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
             // https://tailwindcss.com/docs/background-attachment
@@ -222,21 +203,15 @@ impl TailwindInstruction {
             ["local"] => TailwindBackgroundAttachment::Local.boxed(),
             ["scroll"] => TailwindBackgroundAttachment::Scroll.boxed(),
             // https://tailwindcss.com/docs/background-clip
-            ["clip", "border"] => TailwindBackgroundClip::Border.boxed(),
-            ["clip", "padding"] => TailwindBackgroundClip::Padding.boxed(),
-            ["clip", "content"] => TailwindBackgroundClip::Content.boxed(),
-            ["clip", "text"] => TailwindBackgroundClip::Text.boxed(),
+            ["clip", "border"] => TailwindBackgroundClip::from("border-box").boxed(),
+            ["clip", "padding"] => TailwindBackgroundClip::from("padding-box").boxed(),
+            ["clip", "content"] => TailwindBackgroundClip::from("content-box").boxed(),
+            ["clip", "text"] => TailwindBackgroundClip::from("text").boxed(),
             // https://tailwindcss.com/docs/background-origin
-            ["origin", "padding"] => TailwindBackgroundOrigin::Padding.boxed(),
-            ["origin", "content"] => TailwindBackgroundOrigin::Content.boxed(),
-            ["origin", "border"] => TailwindBackgroundOrigin::Border.boxed(),
+            ["origin", rest @ ..] => TailwindBackgroundOrigin::parse(rest, arbitrary)?.boxed(),
             // https://tailwindcss.com/docs/background-repeat
-            ["repeat"] => TailwindBackgroundRepeat::Repeat.boxed(),
-            ["no", "repeat"] | ["repeat", "none"] => TailwindBackgroundRepeat::None.boxed(),
-            ["repeat", "x"] => TailwindBackgroundRepeat::RepeatX.boxed(),
-            ["repeat", "y"] => TailwindBackgroundRepeat::RepeatY.boxed(),
-            ["repeat", "round"] => TailwindBackgroundRepeat::Round.boxed(),
-            ["repeat", "space"] => TailwindBackgroundRepeat::Space.boxed(),
+            ["no", "repeat"] => TailwindBackgroundRepeat::from("repeat").boxed(),
+            ["repeat", rest @ ..] => TailwindBackgroundRepeat::parse(rest, arbitrary)?.boxed(),
             // https://tailwindcss.com/docs/background-size
             ["auto"] => TailwindBackgroundSize::Auto.boxed(),
             ["cover"] => TailwindBackgroundSize::Cover.boxed(),
@@ -248,21 +223,6 @@ impl TailwindInstruction {
         Ok(out)
     }
 
-    #[inline]
-    fn divide_adaptor(str: &[&str], _arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
-        let out = match str {
-            // https://tailwindcss.com/docs/divide-width
-            ["x"] => todo!(),
-            ["x", _n] => todo!(),
-            ["y"] => todo!(),
-            ["y", _n] => todo!(),
-            // https://tailwindcss.com/docs/divide-style
-            [s @ ("solid" | "dashed" | "dotted" | "double" | "none")] => TailwindDivideStyle::from(*s).boxed(),
-            // https://tailwindcss.com/docs/divide-color
-            _ => return syntax_error!("Unknown divide instructions: {}", str.join("-")),
-        };
-        Ok(out)
-    }
     #[inline]
     fn ring_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
@@ -307,37 +267,6 @@ impl TailwindInstruction {
         };
         Ok(out)
     }
-    #[inline]
-    fn content_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
-        let out = match str {
-            // https://tailwindcss.com/docs/align-content
-            ["center"] => TailwindContent::Center.boxed(),
-            ["start"] => TailwindContent::Start.boxed(),
-            ["end"] => TailwindContent::End.boxed(),
-            ["between"] => TailwindContent::Between.boxed(),
-            ["around"] => TailwindContent::Around.boxed(),
-            ["evenly"] => TailwindContent::Evenly.boxed(),
-            // https://tailwindcss.com/docs/content
-            ["none"] => TailwindContentElement::None.boxed(),
-            // https://tailwindcss.com/docs/content#arbitrary-values
-            [] => TailwindContentElement::parse_arbitrary(arbitrary)?.boxed(),
-            _ => return syntax_error!("Unknown content instructions: {}", str.join("-")),
-        };
-        Ok(out)
-    }
-    #[inline]
-    fn place_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
-        let out = match str {
-            // https://tailwindcss.com/docs/place-content
-            ["content", rest @ ..] => TailwindPlaceContent::parse(rest, arbitrary)?.boxed(),
-            // https://tailwindcss.com/docs/place-items
-            ["items", rest @ ..] => TailwindPlaceItems::parse(rest, arbitrary)?.boxed(),
-            // https://tailwindcss.com/docs/place-self
-            ["self", rest @ ..] => TailwindPlaceSelf::parse(rest, arbitrary)?.boxed(),
-            _ => return syntax_error!("Unknown place instructions: {}", str.join("-")),
-        };
-        Ok(out)
-    }
 
     #[inline]
     fn backdrop_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
@@ -366,21 +295,27 @@ impl TailwindInstruction {
         Ok(out)
     }
     #[inline]
-    fn table_adaptor(str: &[&str], _arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
+    fn table_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
             // https://tailwindcss.com/docs/display#flex
-            // `[]` => This won't happen
-            ["caption"] => TailwindTableLayout::Auto.boxed(),
-            ["right"] => TailwindTableLayout::Auto.boxed(),
-            ["none"] => TailwindTableLayout::Auto.boxed(),
+            // This won't happen
+            [] => TailwindDisplay::from("table").boxed(),
             // https://tailwindcss.com/docs/table-layout
-            ["auto"] => TailwindTableLayout::Auto.boxed(),
-            ["fixed"] => TailwindTableLayout::Fixed.boxed(),
-            _ => return syntax_error!("Unknown table instructions: {}", str.join("-")),
+            _ => TailwindTableLayout::parse(str, arbitrary)?.boxed(),
+        };
+        Ok(out)
+    }
+    #[inline]
+    fn object_adaptor(pattern: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
+        let out = match pattern {
+            // https://tailwindcss.com/docs/object-fit
+            [s @ ("contain" | "cover" | "fill" | "none")] => TailwindObjectFit::from(*s).boxed(),
+            ["scale", "down"] => TailwindObjectFit::from("scale-down").boxed(),
+            // https://tailwindcss.com/docs/object-position
+            _ => TailwindObjectPosition::parse(pattern, arbitrary)?.boxed(),
         };
         Ok(out)
     }
-
     #[inline]
     fn overflow_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
